All Classes and Interfaces
Class
Description
Describes a custom algorithm.
Describes an algorithm image.
An AWS Arn.
When the solution performs AutoML (
performAutoML is true in CreateSolution), Amazon
Personalize determines which recipe, from the specified list, optimizes the given metric.
When the solution performs AutoML (
performAutoML is true in CreateSolution), specifies the
recipe that best optimized the specified metric.
The automatic training configuration to use when
performAutoTraining is true.
Contains information on a batch inference job.
The configuration details of a batch inference job.
The input configuration of a batch inference job.
The output configuration parameters of a batch inference job.
A truncated version of the BatchInferenceJob.
Contains information on a batch segment job.
The input configuration of a batch segment job.
The output configuration parameters of a batch segment job.
A truncated version of the BatchSegmentJob datatype.
An object that describes the deployment of a solution version.
The configuration details of a campaign.
Provides a summary of the properties of a campaign.
Provides a summary of the properties of a campaign update.
Provides the name and range of a categorical hyperparameter.
Provides the name and range of a continuous hyperparameter.
CreateBatchInferenceJobRequest MarshallerCreateBatchSegmentJobRequest MarshallerCreateCampaignRequest MarshallerCreateDataDeletionJobRequest MarshallerCreateDatasetExportJobRequest MarshallerCreateDatasetGroupRequest MarshallerCreateDatasetImportJobRequest MarshallerCreateDatasetRequest MarshallerCreateEventTrackerRequest MarshallerCreateFilterRequest MarshallerCreateMetricAttributionRequest MarshallerCreateRecommenderRequest MarshallerCreateSchemaRequest MarshallerCreateSolutionRequest MarshallerCreateSolutionVersionRequest Marshaller
Describes a job that deletes all references to specific users from an Amazon Personalize dataset group in batches.
Provides a summary of the properties of a data deletion job.
Provides metadata for a dataset.
Describes a job that exports a dataset to an Amazon S3 bucket.
The output configuration parameters of a dataset export job.
Provides a summary of the properties of a dataset export job.
A dataset group is a collection of related datasets (Item interactions, Users, Items, Actions, Action interactions).
Provides a summary of the properties of a dataset group.
Describes a job that imports training data from a data source (Amazon S3 bucket) to an Amazon Personalize dataset.
Provides a summary of the properties of a dataset import job.
Describes the schema for a dataset.
Provides a summary of the properties of a dataset schema.
Provides a summary of the properties of a dataset.
Describes an update to a dataset.
Describes the data source that contains the data to upload to a dataset, or the list of records to delete from Amazon
Personalize.
Provides the name and default range of a categorical hyperparameter and whether the hyperparameter is tunable.
Provides the name and default range of a continuous hyperparameter and whether the hyperparameter is tunable.
Specifies the hyperparameters and their default ranges.
Provides the name and default range of a integer-valued hyperparameter and whether the hyperparameter is tunable.
DeleteCampaignRequest MarshallerDeleteDatasetGroupRequest MarshallerDeleteDatasetRequest MarshallerDeleteEventTrackerRequest MarshallerDeleteFilterRequest MarshallerDeleteMetricAttributionRequest MarshallerDeleteRecommenderRequest MarshallerDeleteSchemaRequest MarshallerDeleteSolutionRequest MarshallerDescribeAlgorithmRequest MarshallerDescribeBatchInferenceJobRequest MarshallerDescribeBatchSegmentJobRequest MarshallerDescribeCampaignRequest MarshallerDescribeDataDeletionJobRequest MarshallerDescribeDatasetExportJobRequest MarshallerDescribeDatasetGroupRequest MarshallerDescribeDatasetImportJobRequest MarshallerDescribeDatasetRequest MarshallerDescribeEventTrackerRequest MarshallerDescribeFeatureTransformationRequest MarshallerDescribeFilterRequest MarshallerDescribeMetricAttributionRequest MarshallerDescribeRecipeRequest MarshallerDescribeRecommenderRequest MarshallerDescribeSchemaRequest MarshallerDescribeSolutionRequest MarshallerDescribeSolutionVersionRequest MarshallerLink between an endpoint property and the
AwsEndpointAttribute it represents.
Describes the parameters of events, which are used in solution creation.
Describes the configuration of events, which are used in solution creation.
Provides information about an event tracker.
Provides a summary of the properties of an event tracker.
Provides feature transformation information.
A string to string map of the configuration details for theme generation.
Contains information on a recommendation filter, including its ARN, status, and filter expression.
A short summary of a filter's attributes.
GetSolutionMetricsRequest Marshaller
Describes the properties for hyperparameter optimization (HPO).
The metric to optimize during hyperparameter optimization (HPO).
Describes the resource configuration for hyperparameter optimization (HPO).
Specifies the hyperparameters and their ranges.
Identifiers for variables declared within the rule engine, e.g.
Provides the name and range of an integer-valued hyperparameter.
Provide a valid value for the field or parameter.
The token is not valid.
The limit on the number of requests per second has been exceeded.
Represents the output for the
PersonalizeClient.listBatchInferenceJobsPaginator(software.amazon.awssdk.services.personalize.model.ListBatchInferenceJobsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listBatchInferenceJobsPaginator(software.amazon.awssdk.services.personalize.model.ListBatchInferenceJobsRequest)
operation which is a paginated operation.ListBatchInferenceJobsRequest Marshaller
Represents the output for the
PersonalizeClient.listBatchSegmentJobsPaginator(software.amazon.awssdk.services.personalize.model.ListBatchSegmentJobsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listBatchSegmentJobsPaginator(software.amazon.awssdk.services.personalize.model.ListBatchSegmentJobsRequest)
operation which is a paginated operation.ListBatchSegmentJobsRequest Marshaller
Represents the output for the
PersonalizeClient.listCampaignsPaginator(software.amazon.awssdk.services.personalize.model.ListCampaignsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listCampaignsPaginator(software.amazon.awssdk.services.personalize.model.ListCampaignsRequest)
operation which is a paginated operation.ListCampaignsRequest MarshallerListDataDeletionJobsRequest Marshaller
Represents the output for the
PersonalizeClient.listDatasetExportJobsPaginator(software.amazon.awssdk.services.personalize.model.ListDatasetExportJobsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listDatasetExportJobsPaginator(software.amazon.awssdk.services.personalize.model.ListDatasetExportJobsRequest)
operation which is a paginated operation.ListDatasetExportJobsRequest Marshaller
Represents the output for the
PersonalizeClient.listDatasetGroupsPaginator(software.amazon.awssdk.services.personalize.model.ListDatasetGroupsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listDatasetGroupsPaginator(software.amazon.awssdk.services.personalize.model.ListDatasetGroupsRequest)
operation which is a paginated operation.ListDatasetGroupsRequest Marshaller
Represents the output for the
PersonalizeClient.listDatasetImportJobsPaginator(software.amazon.awssdk.services.personalize.model.ListDatasetImportJobsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listDatasetImportJobsPaginator(software.amazon.awssdk.services.personalize.model.ListDatasetImportJobsRequest)
operation which is a paginated operation.ListDatasetImportJobsRequest Marshaller
Represents the output for the
PersonalizeClient.listDatasetsPaginator(software.amazon.awssdk.services.personalize.model.ListDatasetsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listDatasetsPaginator(software.amazon.awssdk.services.personalize.model.ListDatasetsRequest)
operation which is a paginated operation.ListDatasetsRequest Marshaller
Represents the output for the
PersonalizeClient.listEventTrackersPaginator(software.amazon.awssdk.services.personalize.model.ListEventTrackersRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listEventTrackersPaginator(software.amazon.awssdk.services.personalize.model.ListEventTrackersRequest)
operation which is a paginated operation.ListEventTrackersRequest Marshaller
Represents the output for the
PersonalizeClient.listFiltersPaginator(software.amazon.awssdk.services.personalize.model.ListFiltersRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listFiltersPaginator(software.amazon.awssdk.services.personalize.model.ListFiltersRequest)
operation which is a paginated operation.ListFiltersRequest Marshaller
Represents the output for the
PersonalizeClient.listMetricAttributionMetricsPaginator(software.amazon.awssdk.services.personalize.model.ListMetricAttributionMetricsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listMetricAttributionMetricsPaginator(software.amazon.awssdk.services.personalize.model.ListMetricAttributionMetricsRequest)
operation which is a paginated operation.ListMetricAttributionMetricsRequest Marshaller
Represents the output for the
PersonalizeClient.listMetricAttributionsPaginator(software.amazon.awssdk.services.personalize.model.ListMetricAttributionsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listMetricAttributionsPaginator(software.amazon.awssdk.services.personalize.model.ListMetricAttributionsRequest)
operation which is a paginated operation.ListMetricAttributionsRequest Marshaller
Represents the output for the
PersonalizeClient.listRecipesPaginator(software.amazon.awssdk.services.personalize.model.ListRecipesRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listRecipesPaginator(software.amazon.awssdk.services.personalize.model.ListRecipesRequest)
operation which is a paginated operation.ListRecipesRequest Marshaller
Represents the output for the
PersonalizeClient.listRecommendersPaginator(software.amazon.awssdk.services.personalize.model.ListRecommendersRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listRecommendersPaginator(software.amazon.awssdk.services.personalize.model.ListRecommendersRequest)
operation which is a paginated operation.ListRecommendersRequest Marshaller
Represents the output for the
PersonalizeClient.listSchemasPaginator(software.amazon.awssdk.services.personalize.model.ListSchemasRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listSchemasPaginator(software.amazon.awssdk.services.personalize.model.ListSchemasRequest)
operation which is a paginated operation.ListSchemasRequest Marshaller
Represents the output for the
PersonalizeClient.listSolutionsPaginator(software.amazon.awssdk.services.personalize.model.ListSolutionsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listSolutionsPaginator(software.amazon.awssdk.services.personalize.model.ListSolutionsRequest)
operation which is a paginated operation.ListSolutionsRequest Marshaller
Represents the output for the
PersonalizeClient.listSolutionVersionsPaginator(software.amazon.awssdk.services.personalize.model.ListSolutionVersionsRequest)
operation which is a paginated operation.
Represents the output for the
PersonalizeAsyncClient.listSolutionVersionsPaginator(software.amazon.awssdk.services.personalize.model.ListSolutionVersionsRequest)
operation which is a paginated operation.ListSolutionVersionsRequest MarshallerListTagsForResourceRequest Marshaller
Contains information on a metric that a metric attribution reports on.
Contains information on a metric attribution.
The output configuration details for a metric attribution.
Provides a summary of the properties of a metric attribution.
Describes the additional objective for the solution, such as maximizing streaming minutes or increasing revenue.
Service client for accessing Amazon Personalize asynchronously.
A builder for creating an instance of
PersonalizeAsyncClient.The parameters object used to resolve the auth schemes for the Personalize service.
A builder for a
PersonalizeAuthSchemeParams.An auth scheme provider for Personalize service.
This includes configuration specific to Amazon Personalize that is supported by both
PersonalizeClientBuilder
and PersonalizeAsyncClientBuilder.Service client for accessing Amazon Personalize.
A builder for creating an instance of
PersonalizeClient.The parameters object used to resolve an endpoint for the Personalize service.
An endpoint provider for Personalize.
Class to expose the service client settings to the user.
A builder for creating a
PersonalizeServiceClientConfiguration
Provides information about a recipe.
Provides a summary of the properties of a recipe.
Describes a recommendation generator for a Domain dataset group.
The configuration details of the recommender.
Provides a summary of the properties of the recommender.
Provides a summary of the properties of a recommender update.
The specified resource already exists.
The specified resource is in use.
Could not find the specified resource.
Represents a URL to be used internally for endpoint resolution.
The configuration details of an Amazon S3 input or output bucket.
Describes the configuration properties for the solution.
Provides a summary of the properties of a solution.
The configuration details of the solution update.
Provides a summary of the properties of a solution update.
An object that provides information about a specific version of a Solution in a Custom dataset group.
Provides a summary of the properties of a solution version.
StartRecommenderRequest MarshallerStopRecommenderRequest MarshallerStopSolutionVersionCreationRequest Marshaller
The optional metadata that you apply to resources to help you categorize and organize them.
TagResourceRequest Marshaller
The configuration details for generating themes with a batch inference job.
The request contains more tag keys than can be associated with a resource (50 tag keys per resource).
You have exceeded the maximum number of tags you can apply to this resource.
The training data configuration to use when creating a domain recommender or custom solution version (trained model).
If hyperparameter optimization (HPO) was performed, contains the hyperparameter values of the best performing model.
UntagResourceRequest MarshallerUpdateCampaignRequest MarshallerUpdateDatasetRequest MarshallerUpdateMetricAttributionRequest MarshallerUpdateRecommenderRequest MarshallerUpdateSolutionRequest MarshallerBase class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.